@@ -5,7 +5,7 @@ from inspect import Parameter
 from typing import Optional, TypeVar, Generic, Type, Iterable
 
 
-@dataclass
+@dataclass(frozen=True, eq=True)
 class Autocompletion:
     """A single auto-completion result."""
 
@@ -45,7 +45,6 @@ class ParameterType(Generic[T]):
     def from_string(self, value: str) -> T:
         """Parses strings into parameter values."""
 
-    # pylint: disable=no-self-use
     def to_string(self, value: T) -> str:
         """Converts parameter values into their string representation."""
         return str(value)
@@ -112,6 +111,11 @@ class BoolParameterType(ParameterType[bool]):
             return False
         raise ValueError("Value must be either 'true' or 'false'")
 
+    def to_string(self, value: bool) -> str:
+        if value:
+            return "true"
+        return "false"
+
 
 class EnumParameterType(ParameterType[Enum]):
     """Enumeration type"""
